=> Bootstrap dependency digest>=20010302: found digest-20121220
=> Bootstrap dependency fetch-[0-9]*: found fetch-1.8nb1
=> Checksum SHA1 OK for firefox-21.0.source.tar.bz2
=> Checksum RMD160 OK for firefox-21.0.source.tar.bz2
===> Installing dependencies for firefox-21.0
==========================================================================
The supported build options for firefox are:

	debug gnome mozilla-jemalloc official-mozilla-branding
	pulseaudio

The currently selected options are:

	mozilla-jemalloc

You can select which build options to use by setting PKG_DEFAULT_OPTIONS
or the following variable.  Its current value is shown:

	PKG_OPTIONS.firefox (not defined)

==========================================================================
==========================================================================
The following variables will affect the build process of this package,
firefox-21.0.  Their current value is shown below:

        * PYTHON_VERSION_DEFAULT = 27
        * SSLBASE (defined)
        * SSLCERTS = /usr/pkg/etc/openssl/certs
        * SSLDIR = /usr/pkg/etc/openssl
        * SSLKEYS = /usr/pkg/etc/openssl/private

Based on these variables, the following variables have been set:

        * PYPACKAGE = python27

You may want to abort the process now with CTRL-C and change their value
before continuing.  Be sure to run `/usr/pkg/bin/bmake clean' after
the changes.
==========================================================================
=> Tool dependency autoconf213>=2.13: found autoconf213-2.13nb2
=> Tool dependency nbpatch-[0-9]*: found nbpatch-20100124
=> Tool dependency perl>=5.0: found perl-5.16.3
=> Tool dependency pkg-config>=0.25: found pkg-config-0.28
=> Tool dependency unzip-[0-9]*: found unzip-6.0nb1
=> Tool dependency zip-[0-9]*: found zip-3.0nb2
=> Tool dependency zip-[0-9]*: found zip-3.0nb2
=> Tool dependency zip-[0-9]*: found zip-3.0nb2
=> Tool dependency zip-[0-9]*: found zip-3.0nb2
=> Tool dependency checkperms>=1.1: found checkperms-1.11
=> Build dependency yasm>=1.1.0: found yasm-1.2.0
=> Build dependency py27-sqlite2-[0-9]*: found py27-sqlite2-2.6.3nb5
=> Build dependency python27>=2.7.1nb2: found python27-2.7.4
=> Build dependency dri2proto>=2.0: found dri2proto-2.8
=> Build dependency glproto>=1.4.6: found glproto-1.4.16
=> Build dependency damageproto>=1.1.0: found damageproto-1.2.1
=> Build dependency xproto>=7.0.9: found xproto-7.0.24nb1
=> Build dependency fixesproto>=3.0.0: found fixesproto-5.0
=> Build dependency xextproto>=7.0: found xextproto-7.2.1
=> Build dependency inputproto>=1.4: found inputproto-2.3
=> Build dependency kbproto>=1.0.2: found kbproto-1.0.6
=> Build dependency xcb-proto>=1.4: found xcb-proto-1.8
=> Build dependency xf86vidmodeproto>=2.3: found xf86vidmodeproto-2.3.1
=> Build dependency xf86driproto>=2.0.3: found xf86driproto-2.1.1
=> Build dependency renderproto>=0.9.3nb1: found renderproto-0.11.1
=> Build dependency randrproto>=1.2.0: found randrproto-1.4.0
=> Build dependency xineramaproto>=1.1.1: found xineramaproto-1.2.1
=> Build dependency compositeproto>=0.3.1: found compositeproto-0.4.2
=> Full dependency alsa-lib>=1.0.18: found alsa-lib-1.0.22
=> Full dependency bzip2>=1.0.3: found bzip2-1.0.6
=> Full dependency sqlite3>=3.7.16.2nb1: found sqlite3-3.7.17
=> Full dependency libevent>=2.0.10: found libevent-2.0.21nb2
=> Full dependency libffi>=3.0.11: found libffi-3.0.13
=> Full dependency nspr>=4.9.4: found nspr-4.9.6
=> Full dependency nss>=3.14.1: found nss-3.14.3nb1
=> Full dependency zlib>=1.2.3: found zlib-1.2.7
=> Full dependency MesaLib>=7.11.2: found MesaLib-7.11.2
=> Full dependency cairo>=1.12.14nb1: found cairo-1.12.14nb1
=> Full dependency libvpx>=1.0.0: found libvpx-1.1.0nb2
=> Full dependency libIDL>=0.8.14nb4: found libIDL-0.8.14nb4
=> Full dependency hunspell>=1.3.2: found hunspell-1.3.2nb1
=> Full dependency gtk2+>=2.24.15nb1: found gtk2+-2.24.17
=> Full dependency libXt>=1.0.0: found libXt-1.1.3
=> Full dependency desktop-file-utils>=0.10nb1: found desktop-file-utils-0.21
===> Overriding tools for firefox-21.0
===> Extracting for firefox-21.0
===> Patching for firefox-21.0
=> Applying pkgsrc patches for firefox-21.0
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-aa
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-aa
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-aa,v 1.19 2013/05/19 08:47:41 ryoon Exp $
|
|--- configure.in.orig	2013-05-11 19:19:23.000000000 +0000
|+++ configure.in
--------------------------
Patching file configure.in using Plan A...
Hunk #1 succeeded at 1404.
Hunk #2 succeeded at 2077.
Hunk #3 succeeded at 2862.
Hunk #4 succeeded at 2871.
Hunk #5 succeeded at 3033.
Hunk #6 succeeded at 3337.
Hunk #7 succeeded at 4010.
Hunk #8 succeeded at 4045.
Hunk #9 succeeded at 5237.
Hunk #10 succeeded at 5292.
Hunk #11 succeeded at 5331.
Hunk #12 succeeded at 5736.
Hunk #13 succeeded at 8343.
Hunk #14 succeeded at 9023.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ak
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ak
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ak,v 1.8 2013/01/10 15:01:30 ryoon Exp $
|
|--- js/src/ctypes/libffi/configure.orig	2013-01-04 23:44:34.000000000 +0000
|+++ js/src/ctypes/libffi/configure
--------------------------
Patching file js/src/ctypes/libffi/configure using Plan A...
Hunk #1 succeeded at 11278.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-al
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-al
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-al,v 1.8 2013/01/10 15:01:30 ryoon Exp $
|
|--- storage/src/mozStorageConnection.cpp.orig	2013-01-04 23:44:44.000000000 +0000
|+++ storage/src/mozStorageConnection.cpp
--------------------------
Patching file storage/src/mozStorageConnection.cpp using Plan A...
Hunk #1 succeeded at 635 (offset 51 lines).
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-am
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-am
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-am,v 1.4 2013/01/10 15:01:30 ryoon Exp $
|
|SHA1_Update conflicts with openssl which may be dynamically loaded
|at runtime via libcups or libgssapi so causing a crash due to using
|the wrong binding.  So rename here to avoid conflict.
|
|--- security/nss/lib/freebl/blapi.h.orig	2013-01-04 23:44:43.000000000 +0000
|+++ security/nss/lib/freebl/blapi.h
--------------------------
Patching file security/nss/lib/freebl/blapi.h using Plan A...
Hunk #1 succeeded at 1022 (offset 12 lines).
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-an
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-an
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-an,v 1.4 2013/01/10 15:01:30 ryoon Exp $
|
|SHA1_Update conflicts with openssl which may be dynamically loaded
|at runtime via libcups or libgssapi so causing a crash due to using
|the wrong binding.  So rename here to avoid conflict.
|
|--- security/nss/lib/freebl/sha-fast-amd64-sun.s.orig	2013-01-04 23:44:43.000000000 +0000
|+++ security/nss/lib/freebl/sha-fast-amd64-sun.s
--------------------------
Patching file security/nss/lib/freebl/sha-fast-amd64-sun.s using Plan A...
Hunk #1 succeeded at 1680.
Hunk #2 succeeded at 1768.
Hunk #3 succeeded at 1870.
Hunk #4 succeeded at 1986.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ao
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ao
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ao,v 1.7 2013/04/05 13:30:17 ryoon Exp $
|
|--- toolkit/mozapps/installer/packager.mk.orig	2013-03-26 22:18:05.000000000 +0000
|+++ toolkit/mozapps/installer/packager.mk
--------------------------
Patching file toolkit/mozapps/installer/packager.mk using Plan A...
No such line 910 in input file, ignoring
Hunk #1 succeeded at 652 (offset -259 lines).
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-as
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-as
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-as,v 1.11 2013/05/19 08:47:41 ryoon Exp $
|
|Treat DragonFly like FreeBSD.
|
|--- js/src/configure.in.orig	2013-05-11 19:19:32.000000000 +0000
|+++ js/src/configure.in
--------------------------
Patching file js/src/configure.in using Plan A...
Hunk #1 succeeded at 2399.
Hunk #2 succeeded at 2408.
Hunk #3 succeeded at 2629.
Hunk #4 succeeded at 2712.
Hunk #5 succeeded at 3490.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-au
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-au
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-au,v 1.8 2013/05/19 08:47:41 ryoon Exp $
|
|- Fix device name on NetBSD
|- SOUND_VERSION just isn't a reliable way to detect features supported by
|  particular OSS implementation.
|
|--- media/libsydneyaudio/src/sydney_audio_oss.c.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/libsydneyaudio/src/sydney_audio_oss.c
--------------------------
Patching file media/libsydneyaudio/src/sydney_audio_oss.c using Plan A...
Hunk #1 succeeded at 23.
Hunk #2 succeeded at 173.
Hunk #3 succeeded at 451.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-az
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-az
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-az,v 1.4 2013/01/10 15:01:30 ryoon Exp $
|
|--- nsprpub/pr/src/pthreads/ptthread.c.orig	2013-01-04 23:44:43.000000000 +0000
|+++ nsprpub/pr/src/pthreads/ptthread.c
--------------------------
Patching file nsprpub/pr/src/pthreads/ptthread.c using Plan A...
Hunk #1 succeeded at 1099 (offset 56 lines).
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ba
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ba
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ba,v 1.4 2013/01/10 15:01:30 ryoon Exp $
|
|pthread_t may be 64-bit, avoid casting it.
|
|--- nsprpub/pr/include/private/pprthred.h.orig	2013-01-04 23:44:43.000000000 +0000
|+++ nsprpub/pr/include/private/pprthred.h
--------------------------
Patching file nsprpub/pr/include/private/pprthred.h using Plan A...
Hunk #1 succeeded at 19.
Hunk #2 succeeded at 61.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-bd
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-bd
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-bd,v 1.5 2013/01/10 15:01:30 ryoon Exp $
|
|--- js/src/ctypes/CTypes.cpp.orig	2013-01-04 23:44:34.000000000 +0000
|+++ js/src/ctypes/CTypes.cpp
--------------------------
Patching file js/src/ctypes/CTypes.cpp using Plan A...
Hunk #1 succeeded at 5.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-bf
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-bf
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-bf,v 1.12 2013/04/05 13:30:17 ryoon Exp $
|
|--- js/src/jsnativestack.cpp.orig	2013-03-26 22:17:48.000000000 +0000
|+++ js/src/jsnativestack.cpp
--------------------------
Patching file js/src/jsnativestack.cpp using Plan A...
Hunk #1 succeeded at 19.
Hunk #2 succeeded at 112.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-bg
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-bg
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-bg,v 1.5 2013/01/10 15:01:30 ryoon Exp $
|
|--- storage/src/SQLiteMutex.h.orig	2013-01-04 23:44:44.000000000 +0000
|+++ storage/src/SQLiteMutex.h
--------------------------
Patching file storage/src/SQLiteMutex.h using Plan A...
Hunk #1 succeeded at 108.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-bi
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-bi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-bi,v 1.7 2013/01/10 15:01:30 ryoon Exp $
|
|--- gfx/angle/src/compiler/osinclude.h.orig	2013-01-04 23:44:32.000000000 +0000
|+++ gfx/angle/src/compiler/osinclude.h
--------------------------
Patching file gfx/angle/src/compiler/osinclude.h using Plan A...
Hunk #1 succeeded at 16.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-build_autoconf_nss.m4
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-build_autoconf_nss.m4
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-build_autoconf_nss.m4,v 1.4 2013/01/10 15:01:30 ryoon Exp $
|
|--- build/autoconf/nss.m4.orig	2013-01-04 23:44:28.000000000 +0000
|+++ build/autoconf/nss.m4
--------------------------
Patching file build/autoconf/nss.m4 using Plan A...
Hunk #1 succeeded at 22.
Hunk #2 succeeded at 41.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-config_baseconfig.mk
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-config_baseconfig.mk
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-config_baseconfig.mk,v 1.2 2013/01/10 15:01:30 ryoon Exp $
|
|--- config/baseconfig.mk.orig	2013-01-04 23:44:28.000000000 +0000
|+++ config/baseconfig.mk
--------------------------
Patching file config/baseconfig.mk using Plan A...
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-config_stl__wrappers_ios
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-config_stl__wrappers_ios
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-config_stl__wrappers_ios,v 1.1 2013/05/14 12:41:02 joerg Exp $
|
|--- config/stl_wrappers/ios.orig	2013-05-13 18:23:07.000000000 +0000
|+++ config/stl_wrappers/ios
--------------------------
(Creating file config/stl_wrappers/ios...)
Patching file config/stl_wrappers/ios using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-config_stl__wrappers_ostream
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-config_stl__wrappers_ostream
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-config_stl__wrappers_ostream,v 1.1 2013/05/14 12:41:02 joerg Exp $
|
|--- config/stl_wrappers/ostream.orig	2013-05-13 18:22:40.000000000 +0000
|+++ config/stl_wrappers/ostream
--------------------------
(Creating file config/stl_wrappers/ostream...)
Patching file config/stl_wrappers/ostream using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-config_system-headers
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-config_system-headers
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-config_system-headers,v 1.5 2013/05/19 08:47:41 ryoon Exp $
|
|--- config/system-headers.orig	2013-05-11 19:19:23.000000000 +0000
|+++ config/system-headers
--------------------------
Patching file config/system-headers using Plan A...
Hunk #1 succeeded at 1126.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-config_system__wrappers_unwind.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-config_system__wrappers_unwind.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-config_system__wrappers_unwind.h,v 1.1 2013/05/14 12:41:02 joerg Exp $
|
|--- config/system_wrappers/unwind.h.orig	2013-05-13 19:56:18.000000000 +0000
|+++ config/system_wrappers/unwind.h
--------------------------
(Creating file config/system_wrappers/unwind.h...)
Patching file config/system_wrappers/unwind.h using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-content_media_AudioStream.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-content_media_AudioStream.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-content_media_AudioStream.cpp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- content/media/AudioStream.cpp.orig	2013-05-11 19:19:24.000000000 +0000
|+++ content/media/AudioStream.cpp
--------------------------
Patching file content/media/AudioStream.cpp using Plan A...
Hunk #1 succeeded at 314.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-extensions_auth_nsAuthGSSAPI.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-extensions_auth_nsAuthGSSAPI.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-extensions_auth_nsAuthGSSAPI.cpp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- extensions/auth/nsAuthGSSAPI.cpp.orig	2013-05-11 19:19:29.000000000 +0000
|+++ extensions/auth/nsAuthGSSAPI.cpp
--------------------------
Patching file extensions/auth/nsAuthGSSAPI.cpp using Plan A...
Hunk #1 succeeded at 39.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-gfx_skia_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-gfx_skia_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-gfx_skia_Makefile.in,v 1.1 2013/01/10 15:01:30 ryoon Exp $
|
|--- gfx/skia/Makefile.in.orig	2013-01-04 23:44:33.000000000 +0000
|+++ gfx/skia/Makefile.in
--------------------------
Patching file gfx/skia/Makefile.in using Plan A...
Hunk #1 succeeded at 356 (offset 1 line).
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-gfx_skia_src_sfnt_SkOTTable__head.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-gfx_skia_src_sfnt_SkOTTable__head.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-gfx_skia_src_sfnt_SkOTTable__head.h,v 1.2 2013/01/10 15:01:30 ryoon Exp $
|
|* Fix build with NetBSD 5's gcc
|
|--- gfx/skia/src/sfnt/SkOTTable_head.h.orig	2013-01-04 23:44:33.000000000 +0000
|+++ gfx/skia/src/sfnt/SkOTTable_head.h
--------------------------
Patching file gfx/skia/src/sfnt/SkOTTable_head.h using Plan A...
Hunk #1 succeeded at 12.
Hunk #2 succeeded at 140.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-gfx_skia_src_sfnt_SkOTTable__name.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-gfx_skia_src_sfnt_SkOTTable__name.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-gfx_skia_src_sfnt_SkOTTable__name.h,v 1.2 2013/01/10 15:01:30 ryoon Exp $
|
|* Fix build with NetBSD 5's gcc
|
|--- gfx/skia/src/sfnt/SkOTTable_name.h.orig	2013-01-04 23:44:33.000000000 +0000
|+++ gfx/skia/src/sfnt/SkOTTable_name.h
--------------------------
Patching file gfx/skia/src/sfnt/SkOTTable_name.h using Plan A...
Hunk #1 succeeded at 12.
Hunk #2 succeeded at 499.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-gfx_skia_src_sfnt_SkSFNTHeader.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-gfx_skia_src_sfnt_SkSFNTHeader.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-gfx_skia_src_sfnt_SkSFNTHeader.h,v 1.2 2013/01/10 15:01:30 ryoon Exp $
|
|* Fix build wth NetBSD 5's gcc
|
|--- gfx/skia/src/sfnt/SkSFNTHeader.h.orig	2013-01-04 23:44:33.000000000 +0000
|+++ gfx/skia/src/sfnt/SkSFNTHeader.h
--------------------------
Patching file gfx/skia/src/sfnt/SkSFNTHeader.h using Plan A...
Hunk #1 succeeded at 15.
Hunk #2 succeeded at 61.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-gfx_thebes_gfxPlatform.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-gfx_thebes_gfxPlatform.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-gfx_thebes_gfxPlatform.cpp,v 1.4 2013/01/10 15:01:30 ryoon Exp $
|
|--- gfx/thebes/gfxPlatform.cpp.orig	2013-01-04 23:44:33.000000000 +0000
|+++ gfx/thebes/gfxPlatform.cpp
--------------------------
Patching file gfx/thebes/gfxPlatform.cpp using Plan A...
Hunk #1 succeeded at 533 (offset 26 lines).
Hunk #2 succeeded at 650 (offset 26 lines).
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-image_decoders_nsJPEGDecoder.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-image_decoders_nsJPEGDecoder.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-image_decoders_nsJPEGDecoder.cpp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- image/decoders/nsJPEGDecoder.cpp.orig	2013-05-11 19:19:31.000000000 +0000
|+++ image/decoders/nsJPEGDecoder.cpp
--------------------------
Patching file image/decoders/nsJPEGDecoder.cpp using Plan A...
Hunk #1 succeeded at 19.
Hunk #2 succeeded at 353.
Hunk #3 succeeded at 362.
Hunk #4 succeeded at 432.
Hunk #5 succeeded at 586.
Hunk #6 succeeded at 900.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ipc_chromium_src_base_message__pump__libevent.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ipc_chromium_src_base_message__pump__libevent.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ipc_chromium_src_base_message__pump__libevent.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- ipc/chromium/src/base/message_pump_libevent.cc.orig	2013-05-11 19:19:32.000000000 +0000
|+++ ipc/chromium/src/base/message_pump_libevent.cc
--------------------------
Patching file ipc/chromium/src/base/message_pump_libevent.cc using Plan A...
Hunk #1 succeeded at 16.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ipc_chromium_src_base_platform__thread__posix.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ipc_chromium_src_base_platform__thread__posix.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ipc_chromium_src_base_platform__thread__posix.cc,v 1.10 2013/03/30 20:03:09 ryoon Exp $
|
|--- ipc/chromium/src/base/platform_thread_posix.cc.orig	2013-03-07 10:48:46.000000000 +0000
|+++ ipc/chromium/src/base/platform_thread_posix.cc
--------------------------
Patching file ipc/chromium/src/base/platform_thread_posix.cc using Plan A...
Hunk #1 succeeded at 10.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ipc_glue_GeckoChildProcessHost.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ipc_glue_GeckoChildProcessHost.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ipc_glue_GeckoChildProcessHost.cpp,v 1.6 2013/01/10 15:01:31 ryoon Exp $
|
|--- ipc/glue/GeckoChildProcessHost.cpp.orig	2013-01-04 23:44:34.000000000 +0000
|+++ ipc/glue/GeckoChildProcessHost.cpp
--------------------------
Patching file ipc/glue/GeckoChildProcessHost.cpp using Plan A...
Hunk #1 succeeded at 4.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ipc_ipdl_ipdl_lower.py
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-ipc_ipdl_ipdl_lower.py
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ipc_ipdl_ipdl_lower.py,v 1.1 2013/01/10 15:01:31 ryoon Exp $
|
|--- ipc/ipdl/ipdl/lower.py.orig	2013-01-04 23:44:34.000000000 +0000
|+++ ipc/ipdl/ipdl/lower.py
--------------------------
Patching file ipc/ipdl/ipdl/lower.py using Plan A...
Hunk #1 succeeded at 1799 (offset 2 lines).
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-js_src_Makefile.in,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- js/src/Makefile.in.orig	2013-05-11 19:19:32.000000000 +0000
|+++ js/src/Makefile.in
--------------------------
Patching file js/src/Makefile.in using Plan A...
Hunk #1 succeeded at 791.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_config_system-headers
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_config_system-headers
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-js_src_config_system-headers,v 1.5 2013/05/19 08:47:41 ryoon Exp $
|
|--- js/src/config/system-headers.orig	2013-05-11 19:19:32.000000000 +0000
|+++ js/src/config/system-headers
--------------------------
Patching file js/src/config/system-headers using Plan A...
Hunk #1 succeeded at 1126.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_jscompartment.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_jscompartment.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-js_src_jscompartment.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- js/src/jscompartment.h.orig	2013-05-11 19:19:34.000000000 +0000
|+++ js/src/jscompartment.h
--------------------------
Patching file js/src/jscompartment.h using Plan A...
Hunk #1 succeeded at 596.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_jspropertycacheinlines.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_jspropertycacheinlines.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-js_src_jspropertycacheinlines.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- js/src/jspropertycacheinlines.h.orig	2013-05-11 19:19:34.000000000 +0000
|+++ js/src/jspropertycacheinlines.h
--------------------------
Patching file js/src/jspropertycacheinlines.h using Plan A...
Hunk #1 succeeded at 32.
Hunk #2 succeeded at 65.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_methodjit_MethodJIT.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_methodjit_MethodJIT.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-js_src_methodjit_MethodJIT.cpp,v 1.5 2013/05/19 08:47:41 ryoon Exp $
|
|# This does not only apply to linux, but all ELF platforms (otherwise the
|# generated code will not be PIC)
|
|--- js/src/methodjit/MethodJIT.cpp.orig	2013-05-11 19:19:34.000000000 +0000
|+++ js/src/methodjit/MethodJIT.cpp
--------------------------
Patching file js/src/methodjit/MethodJIT.cpp using Plan A...
Hunk #1 succeeded at 138.
Hunk #2 succeeded at 152.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_vm_ObjectImpl-inl.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-js_src_vm_ObjectImpl-inl.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-js_src_vm_ObjectImpl-inl.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- js/src/vm/ObjectImpl-inl.h.orig	2013-05-11 19:19:36.000000000 +0000
|+++ js/src/vm/ObjectImpl-inl.h
--------------------------
Patching file js/src/vm/ObjectImpl-inl.h using Plan A...
Hunk #1 succeeded at 164.
Hunk #2 succeeded at 321.
Hunk #3 succeeded at 335.
Hunk #4 succeeded at 362.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-mb
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-mb
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mb,v 1.12 2013/02/24 22:48:59 dholland Exp $
|
|--- xpcom/reflect/xptcall/src/md/unix/Makefile.in.orig	2013-02-15 21:15:14.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/Makefile.in
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/Makefile.in using Plan A...
Hunk #1 succeeded at 50.
Hunk #2 succeeded at 59.
Hunk #3 succeeded at 158.
Hunk #4 succeeded at 215.
Hunk #5 succeeded at 287.
Hunk #6 succeeded at 346.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-md
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-md
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-md,v 1.4 2013/01/10 15:01:31 ryoon Exp $
|
|???. from www/firefox/patch-ax.
|
|--- security/coreconf/SunOS5.mk.orig	2013-01-04 23:44:43.000000000 +0000
|+++ security/coreconf/SunOS5.mk
--------------------------
Patching file security/coreconf/SunOS5.mk using Plan A...
Hunk #1 succeeded at 113 (offset -2 lines).
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-me
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-me
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-me,v 1.8 2013/01/10 15:01:31 ryoon Exp $
|
|Add DragonFly support.
|
|--- security/nss/lib/freebl/Makefile.orig	2013-01-04 23:44:43.000000000 +0000
|+++ security/nss/lib/freebl/Makefile
--------------------------
Patching file security/nss/lib/freebl/Makefile using Plan A...
Hunk #1 succeeded at 257 (offset 2 lines).
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_libsoundtouch_src_cpu__detect__x86.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_libsoundtouch_src_cpu__detect__x86.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_libsoundtouch_src_cpu__detect__x86.cpp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/libsoundtouch/src/cpu_detect_x86.cpp.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/libsoundtouch/src/cpu_detect_x86.cpp
--------------------------
Patching file media/libsoundtouch/src/cpu_detect_x86.cpp using Plan A...
Hunk #1 succeeded at 101.
Hunk #2 succeeded at 112.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_objs.mk
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_objs.mk
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_mtransport_objs.mk,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/mtransport/objs.mk.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/mtransport/objs.mk
--------------------------
Patching file media/mtransport/objs.mk using Plan A...
Hunk #1 succeeded at 23.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_test_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_test_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_mtransport_test_Makefile.in,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/mtransport/test/Makefile.in.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/mtransport/test/Makefile.in
--------------------------
Patching file media/mtransport/test/Makefile.in using Plan A...
Hunk #1 succeeded at 78.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nICEr_nicer.gyp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nICEr_nicer.gyp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_mtransport_third__party_nICEr_nicer.gyp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/mtransport/third_party/nICEr/nicer.gyp.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/mtransport/third_party/nICEr/nicer.gyp
--------------------------
Patching file media/mtransport/third_party/nICEr/nicer.gyp using Plan A...
Hunk #1 succeeded at 129.
Hunk #2 succeeded at 149.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nICEr_src_stun_addrs.c
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nICEr_src_stun_addrs.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_mtransport_third__party_nICEr_src_stun_addrs.c,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/mtransport/third_party/nICEr/src/stun/addrs.c.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/mtransport/third_party/nICEr/src/stun/addrs.c
--------------------------
Patching file media/mtransport/third_party/nICEr/src/stun/addrs.c using Plan A...
Hunk #1 succeeded at 55.
Hunk #2 succeeded at 82.
Hunk #3 succeeded at 692.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nICEr_src_stun_stun.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nICEr_src_stun_stun.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_mtransport_third__party_nICEr_src_stun_stun.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/mtransport/third_party/nICEr/src/stun/stun.h.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/mtransport/third_party/nICEr/src/stun/stun.h
--------------------------
Patching file media/mtransport/third_party/nICEr/src/stun/stun.h using Plan A...
Hunk #1 succeeded at 41.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nICEr_src_util_mbslen.c
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nICEr_src_util_mbslen.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_mtransport_third__party_nICEr_src_util_mbslen.c,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/mtransport/third_party/nICEr/src/util/mbslen.c.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/mtransport/third_party/nICEr/src/util/mbslen.c
--------------------------
Patching file media/mtransport/third_party/nICEr/src/util/mbslen.c using Plan A...
Hunk #1 succeeded at 43.
Hunk #2 succeeded at 62.
Hunk #3 succeeded at 75.
Hunk #4 succeeded at 84.
Hunk #5 succeeded at 106.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nrappkit_nrappkit.gyp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nrappkit_nrappkit.gyp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_mtransport_third__party_nrappkit_nrappkit.gyp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/mtransport/third_party/nrappkit/nrappkit.gyp.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/mtransport/third_party/nrappkit/nrappkit.gyp
--------------------------
Patching file media/mtransport/third_party/nrappkit/nrappkit.gyp using Plan A...
Hunk #1 succeeded at 147.
Hunk #2 succeeded at 166.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nrappkit_src_log_r__log.c
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nrappkit_src_log_r__log.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_mtransport_third__party_nrappkit_src_log_r__log.c,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/mtransport/third_party/nrappkit/src/log/r_log.c.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/mtransport/third_party/nrappkit/src/log/r_log.c
--------------------------
Patching file media/mtransport/third_party/nrappkit/src/log/r_log.c using Plan A...
Hunk #1 succeeded at 48.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nrappkit_src_port_generic_include_sys_queue.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nrappkit_src_port_generic_include_sys_queue.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_mtransport_third__party_nrappkit_src_port_generic_include_sys_queue.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/mtransport/third_party/nrappkit/src/port/generic/include/sys/queue.h.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/mtransport/third_party/nrappkit/src/port/generic/include/sys/queue.h
--------------------------
Patching file media/mtransport/third_party/nrappkit/src/port/generic/include/sys/queue.h using Plan A...
Hunk #1 succeeded at 33.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nrappkit_src_util_util.c
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_mtransport_third__party_nrappkit_src_util_util.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_mtransport_third__party_nrappkit_src_util_util.c,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/mtransport/third_party/nrappkit/src/util/util.c.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/mtransport/third_party/nrappkit/src/util/util.c
--------------------------
Patching file media/mtransport/third_party/nrappkit/src/util/util.c using Plan A...
Hunk #1 succeeded at 45.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_signaling_signaling.gyp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_signaling_signaling.gyp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_signaling_signaling.gyp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/signaling/signaling.gyp.orig	2013-05-11 19:19:44.000000000 +0000
|+++ media/webrtc/signaling/signaling.gyp
--------------------------
Patching file media/webrtc/signaling/signaling.gyp using Plan A...
Hunk #1 succeeded at 217.
Hunk #2 succeeded at 765.
Hunk #3 succeeded at 810.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_signaling_src_sipcc_cpr_darwin_cpr__darwin__ipc.c
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_signaling_src_sipcc_cpr_darwin_cpr__darwin__ipc.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_signaling_src_sipcc_cpr_darwin_cpr__darwin__ipc.c,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/signaling/src/sipcc/cpr/darwin/cpr_darwin_ipc.c.orig	2013-05-11 19:19:44.000000000 +0000
|+++ media/webrtc/signaling/src/sipcc/cpr/darwin/cpr_darwin_ipc.c
--------------------------
Patching file media/webrtc/signaling/src/sipcc/cpr/darwin/cpr_darwin_ipc.c using Plan A...
Hunk #1 succeeded at 322.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_signaling_test_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_signaling_test_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_signaling_test_Makefile.in,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/signaling/test/Makefile.in.orig	2013-05-11 19:19:44.000000000 +0000
|+++ media/webrtc/signaling/test/Makefile.in
--------------------------
Patching file media/webrtc/signaling/test/Makefile.in using Plan A...
Hunk #1 succeeded at 17.
Hunk #2 succeeded at 87.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_build_common.gypi
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_build_common.gypi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_build_common.gypi,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/build/common.gypi.orig	2013-05-11 19:19:44.000000000 +0000
|+++ media/webrtc/trunk/build/common.gypi
--------------------------
Patching file media/webrtc/trunk/build/common.gypi using Plan A...
Hunk #1 succeeded at 80.
Hunk #2 succeeded at 128.
Hunk #3 succeeded at 153.
Hunk #4 succeeded at 416.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_testing_gtest_include_gtest_internal_gtest-port.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_testing_gtest_include_gtest_internal_gtest-port.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_testing_gtest_include_gtest_internal_gtest-port.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/testing/gtest/include/gtest/internal/gtest-port.h.orig	2013-05-11 19:19:44.000000000 +0000
|+++ media/webrtc/trunk/testing/gtest/include/gtest/internal/gtest-port.h
--------------------------
Patching file media/webrtc/trunk/testing/gtest/include/gtest/internal/gtest-port.h using Plan A...
Hunk #1 succeeded at 490.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_third__party_libyuv_libyuv.gyp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_third__party_libyuv_libyuv.gyp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_third__party_libyuv_libyuv.gyp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/third_party/libyuv/libyuv.gyp.orig	2013-05-11 19:19:44.000000000 +0000
|+++ media/webrtc/trunk/third_party/libyuv/libyuv.gyp
--------------------------
Patching file media/webrtc/trunk/third_party/libyuv/libyuv.gyp using Plan A...
Hunk #1 succeeded at 9.
Hunk #2 succeeded at 51.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_tools_gyp_pylib_gyp_generator_mozmake.py
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_tools_gyp_pylib_gyp_generator_mozmake.py
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_tools_gyp_pylib_gyp_generator_mozmake.py,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/tools/gyp/pylib/gyp/generator/mozmake.py.orig	2013-05-11 19:19:44.000000000 +0000
|+++ media/webrtc/trunk/tools/gyp/pylib/gyp/generator/mozmake.py
--------------------------
Patching file media/webrtc/trunk/tools/gyp/pylib/gyp/generator/mozmake.py using Plan A...
Hunk #1 succeeded at 9.
Hunk #2 succeeded at 112.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_build_common.gypi
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_build_common.gypi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_build_common.gypi,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/build/common.gypi.orig	2013-05-11 19:19:44.000000000 +0000
|+++ media/webrtc/trunk/webrtc/build/common.gypi
--------------------------
Patching file media/webrtc/trunk/webrtc/build/common.gypi using Plan A...
Hunk #1 succeeded at 124.
Hunk #2 succeeded at 215.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_audio__device_audio__device.gypi
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_audio__device_audio__device.gypi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_modules_audio__device_audio__device.gypi,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/modules/audio_device/audio_device.gypi.orig	2013-05-11 19:19:45.000000000 +0000
|+++ media/webrtc/trunk/webrtc/modules/audio_device/audio_device.gypi
--------------------------
Patching file media/webrtc/trunk/webrtc/modules/audio_device/audio_device.gypi using Plan A...
Hunk #1 succeeded at 45.
Hunk #2 succeeded at 81.
Hunk #3 succeeded at 132.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_audio__device_audio__device__utility.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_audio__device_audio__device__utility.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_modules_audio__device_audio__device__utility.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/modules/audio_device/audio_device_utility.cc.orig	2013-05-11 19:19:45.000000000 +0000
|+++ media/webrtc/trunk/webrtc/modules/audio_device/audio_device_utility.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/modules/audio_device/audio_device_utility.cc using Plan A...
Hunk #1 succeeded at 46.
Hunk #2 succeeded at 109.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_forward__error__correction.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_forward__error__correction.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_forward__error__correction.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/forward_error_correction.cc.orig	2013-05-11 19:19:45.000000000 +0000
|+++ media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/forward_error_correction.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/forward_error_correction.cc using Plan A...
Hunk #1 succeeded at 12.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_rtp__utility.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_rtp__utility.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_rtp__utility.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/rtp_utility.cc.orig	2013-05-11 19:19:45.000000000 +0000
|+++ media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/rtp_utility.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/rtp_utility.cc using Plan A...
Hunk #1 succeeded at 18.
Hunk #2 succeeded at 156.
Hunk #3 succeeded at 214.
Hunk #4 succeeded at 253.
Hunk #5 succeeded at 330.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_udp__transport_source_udp__transport__impl.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_udp__transport_source_udp__transport__impl.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_modules_udp__transport_source_udp__transport__impl.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/modules/udp_transport/source/udp_transport_impl.cc.orig	2013-05-11 19:19:45.000000000 +0000
|+++ media/webrtc/trunk/webrtc/modules/udp_transport/source/udp_transport_impl.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/modules/udp_transport/source/udp_transport_impl.cc using Plan A...
Hunk #1 succeeded at 18.
Hunk #2 succeeded at 36.
Hunk #3 succeeded at 53.
Hunk #4 succeeded at 63.
Hunk #5 succeeded at 2373.
Hunk #6 succeeded at 2495.
Hunk #7 succeeded at 2687.
Hunk #8 succeeded at 2826.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_utility_source_rtp__dump__impl.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_utility_source_rtp__dump__impl.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_modules_utility_source_rtp__dump__impl.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/modules/utility/source/rtp_dump_impl.cc.orig	2013-05-11 19:19:45.000000000 +0000
|+++ media/webrtc/trunk/webrtc/modules/utility/source/rtp_dump_impl.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/modules/utility/source/rtp_dump_impl.cc using Plan A...
Hunk #1 succeeded at 19.
Hunk #2 succeeded at 238.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_video__capture_device__info__impl.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_video__capture_device__info__impl.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_modules_video__capture_device__info__impl.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/modules/video_capture/device_info_impl.cc.orig	2013-05-11 19:19:45.000000000 +0000
|+++ media/webrtc/trunk/webrtc/modules/video_capture/device_info_impl.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/modules/video_capture/device_info_impl.cc using Plan A...
Hunk #1 succeeded at 54.
Hunk #2 succeeded at 91.
Hunk #3 succeeded at 155.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_video__capture_linux_device__info__linux.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_video__capture_linux_device__info__linux.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_modules_video__capture_linux_device__info__linux.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/modules/video_capture/linux/device_info_linux.cc.orig	2013-05-11 19:19:45.000000000 +0000
|+++ media/webrtc/trunk/webrtc/modules/video_capture/linux/device_info_linux.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/modules/video_capture/linux/device_info_linux.cc using Plan A...
Hunk #1 succeeded at 19.
Hunk #2 succeeded at 148.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_video__capture_linux_video__capture__linux.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_video__capture_linux_video__capture__linux.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_modules_video__capture_linux_video__capture__linux.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/modules/video_capture/linux/video_capture_linux.cc.orig	2013-05-11 19:19:45.000000000 +0000
|+++ media/webrtc/trunk/webrtc/modules/video_capture/linux/video_capture_linux.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/modules/video_capture/linux/video_capture_linux.cc using Plan A...
Hunk #1 succeeded at 12.
Hunk #2 succeeded at 37.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_video__capture_video__capture.gypi
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_modules_video__capture_video__capture.gypi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_modules_video__capture_video__capture.gypi,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/modules/video_capture/video_capture.gypi.orig	2013-05-11 19:19:45.000000000 +0000
|+++ media/webrtc/trunk/webrtc/modules/video_capture/video_capture.gypi
--------------------------
Patching file media/webrtc/trunk/webrtc/modules/video_capture/video_capture.gypi using Plan A...
Hunk #1 succeeded at 7.
Hunk #2 succeeded at 51.
Hunk #3 succeeded at 170.
Hunk #4 succeeded at 178.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_interface_asm__defines.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_interface_asm__defines.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_system__wrappers_interface_asm__defines.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/system_wrappers/interface/asm_defines.h.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/system_wrappers/interface/asm_defines.h
--------------------------
Patching file media/webrtc/trunk/webrtc/system_wrappers/interface/asm_defines.h using Plan A...
Hunk #1 succeeded at 11.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_interface_tick__util.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_interface_tick__util.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_system__wrappers_interface_tick__util.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/system_wrappers/interface/tick_util.h.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/system_wrappers/interface/tick_util.h
--------------------------
Patching file media/webrtc/trunk/webrtc/system_wrappers/interface/tick_util.h using Plan A...
Hunk #1 succeeded at 194.
Hunk #2 succeeded at 241.
Hunk #3 succeeded at 258.
Hunk #4 succeeded at 278.
Hunk #5 succeeded at 294.
Hunk #6 succeeded at 323.
Hunk #7 succeeded at 342.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_atomic32__posix.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_atomic32__posix.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_system__wrappers_source_atomic32__posix.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/system_wrappers/source/atomic32_posix.cc.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/system_wrappers/source/atomic32_posix.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/system_wrappers/source/atomic32_posix.cc using Plan A...
Hunk #1 succeeded at 12.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable.cc.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable.cc using Plan A...
Hunk #1 succeeded at 8.
Hunk #2 succeeded at 25.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable__posix.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable__posix.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable__posix.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable_posix.cc.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable_posix.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable_posix.cc using Plan A...
Hunk #1 succeeded at 79.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_cpu.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_cpu.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_system__wrappers_source_cpu.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/system_wrappers/source/cpu.cc.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/system_wrappers/source/cpu.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/system_wrappers/source/cpu.cc using Plan A...
Hunk #1 succeeded at 14.
Hunk #2 succeeded at 26.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_cpu__info.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_cpu__info.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_system__wrappers_source_cpu__info.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/system_wrappers/source/cpu_info.cc.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/system_wrappers/source/cpu_info.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/system_wrappers/source/cpu_info.cc using Plan A...
Hunk #1 succeeded at 12.
Hunk #2 succeeded at 43.
Hunk #3 succeeded at 63.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_spreadsortlib_spreadsort.hpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_spreadsortlib_spreadsort.hpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_system__wrappers_source_spreadsortlib_spreadsort.hpp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/system_wrappers/source/spreadsortlib/spreadsort.hpp.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/system_wrappers/source/spreadsortlib/spreadsort.hpp
--------------------------
Patching file media/webrtc/trunk/webrtc/system_wrappers/source/spreadsortlib/spreadsort.hpp using Plan A...
Hunk #1 succeeded at 21.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_thread__posix.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_thread__posix.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_system__wrappers_source_thread__posix.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/system_wrappers/source/thread_posix.cc.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/system_wrappers/source/thread_posix.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/system_wrappers/source/thread_posix.cc using Plan A...
Hunk #1 succeeded at 59.
Hunk #2 succeeded at 152.
Hunk #3 succeeded at 197.
Hunk #4 succeeded at 262.
Hunk #5 succeeded at 281.
Hunk #6 succeeded at 359.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_trace__posix.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_system__wrappers_source_trace__posix.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_system__wrappers_source_trace__posix.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/system_wrappers/source/trace_posix.cc.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/system_wrappers/source/trace_posix.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/system_wrappers/source/trace_posix.cc using Plan A...
Hunk #1 succeeded at 54.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_typedefs.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_typedefs.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_typedefs.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/typedefs.h.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/typedefs.h
--------------------------
Patching file media/webrtc/trunk/webrtc/typedefs.h using Plan A...
Hunk #1 succeeded at 21.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_video__engine_vie__defines.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_video__engine_vie__defines.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_video__engine_vie__defines.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/video_engine/vie_defines.h.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/video_engine/vie_defines.h
--------------------------
Patching file media/webrtc/trunk/webrtc/video_engine/vie_defines.h using Plan A...
Hunk #1 succeeded at 173.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_voice__engine_voe__network__impl.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_voice__engine_voe__network__impl.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_voice__engine_voe__network__impl.cc,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/voice_engine/voe_network_impl.cc.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/voice_engine/voe_network_impl.cc
--------------------------
Patching file media/webrtc/trunk/webrtc/voice_engine/voe_network_impl.cc using Plan A...
Hunk #1 succeeded at 472.
Hunk #2 succeeded at 528.
Hunk #3 succeeded at 551.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_voice__engine_voice__engine__defines.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_trunk_webrtc_voice__engine_voice__engine__defines.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_trunk_webrtc_voice__engine_voice__engine__defines.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/trunk/webrtc/voice_engine/voice_engine_defines.h.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/trunk/webrtc/voice_engine/voice_engine_defines.h
--------------------------
Patching file media/webrtc/trunk/webrtc/voice_engine/voice_engine_defines.h using Plan A...
Hunk #1 succeeded at 414.
Hunk #2 succeeded at 431.
Hunk #3 succeeded at 440.
Hunk #4 succeeded at 533.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_webrtc__config.gypi
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-media_webrtc_webrtc__config.gypi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-media_webrtc_webrtc__config.gypi,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/webrtc/webrtc_config.gypi.orig	2013-05-11 19:19:46.000000000 +0000
|+++ media/webrtc/webrtc_config.gypi
--------------------------
Patching file media/webrtc/webrtc_config.gypi using Plan A...
Hunk #1 succeeded at 14.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-mp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-mp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mp,v 1.10 2013/05/19 08:47:41 ryoon Exp $
|
|--- media/libsydneyaudio/src/Makefile.in.orig	2013-05-11 19:19:43.000000000 +0000
|+++ media/libsydneyaudio/src/Makefile.in
--------------------------
Patching file media/libsydneyaudio/src/Makefile.in using Plan A...
Hunk #1 succeeded at 70.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-netwerk_sctp_src_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-netwerk_sctp_src_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-netwerk_sctp_src_Makefile.in,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- netwerk/sctp/src/Makefile.in.orig	2013-05-11 19:19:49.000000000 +0000
|+++ netwerk/sctp/src/Makefile.in
--------------------------
Patching file netwerk/sctp/src/Makefile.in using Plan A...
Hunk #1 succeeded at 114.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-netwerk_sctp_src_netinet_sctp__os__userspace.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-netwerk_sctp_src_netinet_sctp__os__userspace.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-netwerk_sctp_src_netinet_sctp__os__userspace.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- netwerk/sctp/src/netinet/sctp_os_userspace.h.orig	2013-05-11 19:19:49.000000000 +0000
|+++ netwerk/sctp/src/netinet/sctp_os_userspace.h
--------------------------
Patching file netwerk/sctp/src/netinet/sctp_os_userspace.h using Plan A...
Hunk #1 succeeded at 395.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-netwerk_sctp_src_user__recv__thread.c
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-netwerk_sctp_src_user__recv__thread.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-netwerk_sctp_src_user__recv__thread.c,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- netwerk/sctp/src/user_recv_thread.c.orig	2013-05-11 19:19:49.000000000 +0000
|+++ netwerk/sctp/src/user_recv_thread.c
--------------------------
Patching file netwerk/sctp/src/user_recv_thread.c using Plan A...
Hunk #1 succeeded at 35.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-netwerk_sctp_src_user__socketvar.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-netwerk_sctp_src_user__socketvar.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-netwerk_sctp_src_user__socketvar.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- netwerk/sctp/src/user_socketvar.h.orig	2013-05-11 19:19:49.000000000 +0000
|+++ netwerk/sctp/src/user_socketvar.h
--------------------------
Patching file netwerk/sctp/src/user_socketvar.h using Plan A...
Hunk #1 succeeded at 47.
Hunk #2 succeeded at 64.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-pa
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-pa
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-pa,v 1.7 2013/01/10 15:01:31 ryoon Exp $
|
|--- xulrunner/installer/mozilla-js.pc.in.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xulrunner/installer/mozilla-js.pc.in
--------------------------
Patching file xulrunner/installer/mozilla-js.pc.in using Plan A...
Hunk #1 succeeded at 6.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-pb
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-pb
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-pb,v 1.8 2013/01/10 15:01:31 ryoon Exp $
|
|--- xulrunner/installer/libxul.pc.in.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xulrunner/installer/libxul.pc.in
--------------------------
Patching file xulrunner/installer/libxul.pc.in using Plan A...
Hunk #1 succeeded at 7.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-pc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-pc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-pc,v 1.7 2013/01/10 15:01:31 ryoon Exp $
|
|--- xulrunner/installer/libxul-embedding.pc.in.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xulrunner/installer/libxul-embedding.pc.in
--------------------------
Patching file xulrunner/installer/libxul-embedding.pc.in using Plan A...
Hunk #1 succeeded at 6.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-pd
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-pd
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-pd,v 1.8 2013/01/10 15:01:31 ryoon Exp $
|
|--- xulrunner/installer/mozilla-nss.pc.in.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xulrunner/installer/mozilla-nss.pc.in
--------------------------
Patching file xulrunner/installer/mozilla-nss.pc.in using Plan A...
Hunk #1 succeeded at 6.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-pg
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-pg
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-pg,v 1.7 2013/01/10 15:01:31 ryoon Exp $
|
|--- xulrunner/installer/mozilla-nspr.pc.in.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xulrunner/installer/mozilla-nspr.pc.in
--------------------------
Patching file xulrunner/installer/mozilla-nspr.pc.in using Plan A...
Hunk #1 succeeded at 5.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-rc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-rc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-rc,v 1.8 2013/01/10 15:01:31 ryoon Exp $
|
|--- browser/branding/unofficial/locales/en-US/brand.dtd.orig	2013-01-04 23:44:28.000000000 +0000
|+++ browser/branding/unofficial/locales/en-US/brand.dtd
--------------------------
Patching file browser/branding/unofficial/locales/en-US/brand.dtd using Plan A...
Hunk #1 succeeded at 2.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-security_manager_ssl_src_nsNSSComponent.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-security_manager_ssl_src_nsNSSComponent.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-security_manager_ssl_src_nsNSSComponent.cpp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- security/manager/ssl/src/nsNSSComponent.cpp.orig	2013-05-11 19:19:50.000000000 +0000
|+++ security/manager/ssl/src/nsNSSComponent.cpp
--------------------------
Patching file security/manager/ssl/src/nsNSSComponent.cpp using Plan A...
Hunk #1 succeeded at 72.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-toolkit_library_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-toolkit_library_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-toolkit_library_Makefile.in,v 1.4 2013/05/19 08:47:41 ryoon Exp $
|
|--- toolkit/library/Makefile.in.orig	2013-05-11 19:19:54.000000000 +0000
|+++ toolkit/library/Makefile.in
--------------------------
Patching file toolkit/library/Makefile.in using Plan A...
Hunk #1 succeeded at 405.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-toolkit_toolkit-tiers.mk
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-toolkit_toolkit-tiers.mk
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-toolkit_toolkit-tiers.mk,v 1.6 2013/01/10 15:01:31 ryoon Exp $
|
|--- toolkit/toolkit-tiers.mk.orig	2013-01-04 23:44:46.000000000 +0000
|+++ toolkit/toolkit-tiers.mk
--------------------------
Patching file toolkit/toolkit-tiers.mk using Plan A...
Hunk #1 succeeded at 63 (offset 20 lines).
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xa
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xa
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xa,v 1.3 2013/01/10 15:01:31 ryoon Exp $
|
|NetBSD/sparc64 xptcall support code. From pkgsrc/www/firefox3/files/
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_sparc64_netbsd.s.orig	2013-01-09 15:25:54.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_sparc64_netbsd.s
--------------------------
(Creating file xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_sparc64_netbsd.s...)
Patching file xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_sparc64_netbsd.s using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xb
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xb
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xb,v 1.3 2013/01/10 15:01:31 ryoon Exp $
|
|NetBSD/sparc64 xptcall support code. From pkgsrc/www/firefox3/files/
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcinvoke_sparc64_netbsd.cpp.orig	2013-01-09 15:25:54.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcinvoke_sparc64_netbsd.cpp
--------------------------
(Creating file xpcom/reflect/xptcall/src/md/unix/xptcinvoke_sparc64_netbsd.cpp...)
Patching file xpcom/reflect/xptcall/src/md/unix/xptcinvoke_sparc64_netbsd.cpp using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xc
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xc,v 1.3 2013/01/10 15:01:31 ryoon Exp $
|
|NetBSD/sparc64 xptcall support code. From pkgsrc/www/firefox3/files/
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_sparc64_netbsd.s.orig	2013-01-09 15:25:54.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_sparc64_netbsd.s
--------------------------
(Creating file xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_sparc64_netbsd.s...)
Patching file xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_sparc64_netbsd.s using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xd
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xd
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xd,v 1.4 2013/01/10 15:01:31 ryoon Exp $
|
|NetBSD/sparc64 xptcall support code. From pkgsrc/www/firefox3/files/
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcstubs_sparc64_netbsd.cpp.orig	2013-01-09 15:25:54.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcstubs_sparc64_netbsd.cpp
--------------------------
(Creating file xpcom/reflect/xptcall/src/md/unix/xptcstubs_sparc64_netbsd.cpp...)
Patching file xpcom/reflect/xptcall/src/md/unix/xptcstubs_sparc64_netbsd.cpp using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xe
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xe
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xe,v 1.5 2013/01/10 15:01:31 ryoon Exp $
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcinvoke_netbsd_m68k.cpp.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcinvoke_netbsd_m68k.cpp
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/xptcinvoke_netbsd_m68k.cpp using Plan A...
Hunk #1 succeeded at 100.
Hunk #2 succeeded at 116.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xf
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xf
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xf,v 1.5 2013/01/10 15:01:31 ryoon Exp $
|
|NetBSD/m68k xptcall support code. From pkgsrc/www/firefox/patch-ae.
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcstubs_netbsd_m68k.cpp.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcstubs_netbsd_m68k.cpp
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/xptcstubs_netbsd_m68k.cpp using Plan A...
Hunk #1 succeeded at 91.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xg
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xg
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xg,v 1.3 2013/01/10 15:01:31 ryoon Exp $
|
|NetBSD/arm xptcall support code. From pkgsrc/www/firefox/patch-bm.
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcstubs_arm_netbsd.cpp.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcstubs_arm_netbsd.cpp
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/xptcstubs_arm_netbsd.cpp using Plan A...
Hunk #1 succeeded at 86.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xj
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xj
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xj,v 1.4 2013/01/10 15:01:31 ryoon Exp $
|
|NetBSD ppc xptcall support code. Originally from pkgsrc/www/mozilla.
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcstubs_ppc_netbsd.cpp.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcstubs_ppc_netbsd.cpp
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/xptcstubs_ppc_netbsd.cpp using Plan A...
Hunk #1 succeeded at 6.
Hunk #2 succeeded at 37.
Hunk #3 succeeded at 44.
Hunk #4 succeeded at 80.
Hunk #5 succeeded at 93.
Hunk #6 succeeded at 144.
Hunk #7 succeeded at 160.
Hunk #8 succeeded at 173.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xk
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xk
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xk,v 1.4 2013/01/10 15:01:31 ryoon Exp $
|
|NetBSD ppc xptcall support code. Originally from pkgsrc/www/mozilla.
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_ppc_netbsd.s.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_ppc_netbsd.s
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_ppc_netbsd.s using Plan A...
Hunk #1 succeeded at 25.
Hunk #2 succeeded at 50.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xl
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xl
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xl,v 1.5 2013/01/10 15:01:32 ryoon Exp $
|
|NetBSD ppc xptcall support code. Originally from pkgsrc/www/mozilla.
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_ppc_netbsd.s.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_ppc_netbsd.s
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_ppc_netbsd.s using Plan A...
Hunk #1 succeeded at 20.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xm
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xm
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xm,v 1.5 2013/01/10 15:01:32 ryoon Exp $
|
|NetBSD/ppc xptcall support code. Originally from pkgsrc/www/mozilla.
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcinvoke_ppc_netbsd.cpp.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcinvoke_ppc_netbsd.cpp
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/xptcinvoke_ppc_netbsd.cpp using Plan A...
Hunk #1 succeeded at 5.
Hunk #2 succeeded at 69.
Hunk #3 succeeded at 81.
Hunk #4 succeeded at 111.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xn
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xn
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xn,v 1.4 2013/01/10 15:01:32 ryoon Exp $
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_mips.s.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_mips.s
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_mips.s using Plan A...
Hunk #1 succeeded at 16.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xo
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xo
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xo,v 1.4 2013/01/10 15:01:32 ryoon Exp $
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_mips.s.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_mips.s
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_mips.s using Plan A...
Hunk #1 succeeded at 14.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xpcom_Makefile.in,v 1.5 2013/03/28 14:10:45 ryoon Exp $
|
|--- xpcom/Makefile.in.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xpcom/Makefile.in
--------------------------
Patching file xpcom/Makefile.in using Plan A...
Hunk #1 succeeded at 35.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_ds_TimeStamp.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_ds_TimeStamp.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xpcom_ds_TimeStamp.h,v 1.2 2013/01/10 15:01:32 ryoon Exp $
|
|http://gnats.netbsd.org/47233
|
|--- xpcom/ds/TimeStamp.h.orig	2013-01-04 23:44:47.000000000 +0000
|+++ xpcom/ds/TimeStamp.h
--------------------------
Patching file xpcom/ds/TimeStamp.h using Plan A...
Hunk #1 succeeded at 151 (offset 21 lines).
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_io_nsMultiplexInputStream_cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_io_nsMultiplexInputStream_cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xpcom_io_nsMultiplexInputStream_cpp,v 1.2 2013/05/19 08:47:41 ryoon Exp $
|
|Fix PR/47722, dragonfly (gcc 4.7) build problem:
|error: no matching function for call to 
|   'NS_MIN(int64_t&, __gnu_cxx::__enable_if<true, double>::__type)'
|devel/xulrunner/work/mozilla-release/xpcom/io/nsMultiplexInputStream.cpp:532:83
|
|--- xpcom/io/nsMultiplexInputStream.cpp.orig	2013-05-11 19:19:56.000000000 +0000
|+++ xpcom/io/nsMultiplexInputStream.cpp
--------------------------
Patching file xpcom/io/nsMultiplexInputStream.cpp using Plan A...
Hunk #1 succeeded at 529.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_reflect_xptcall_src_md_unix_xptcinvoke__gcc__x86__unix.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_reflect_xptcall_src_md_unix_xptcinvoke__gcc__x86__unix.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xpcom_reflect_xptcall_src_md_unix_xptcinvoke__gcc__x86__unix.cpp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcinvoke_gcc_x86_unix.cpp.orig	2013-05-11 19:19:56.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcinvoke_gcc_x86_unix.cpp
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/xptcinvoke_gcc_x86_unix.cpp using Plan A...
Hunk #1 succeeded at 9.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_reflect_xptcall_src_md_unix_xptcstubs__gcc__x86__unix.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_reflect_xptcall_src_md_unix_xptcstubs__gcc__x86__unix.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xpcom_reflect_xptcall_src_md_unix_xptcstubs__gcc__x86__unix.cpp,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- xpcom/reflect/xptcall/src/md/unix/xptcstubs_gcc_x86_unix.cpp.orig	2013-05-11 19:19:56.000000000 +0000
|+++ xpcom/reflect/xptcall/src/md/unix/xptcstubs_gcc_x86_unix.cpp
--------------------------
Patching file xpcom/reflect/xptcall/src/md/unix/xptcstubs_gcc_x86_unix.cpp using Plan A...
Hunk #1 succeeded at 10.
done
=> Verifying /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_string_public_nsAlgorithm.h
=> Applying pkgsrc patch /usr/pkgsrc/www/firefox/../../devel/xulrunner/patches/patch-xpcom_string_public_nsAlgorithm.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xpcom_string_public_nsAlgorithm.h,v 1.1 2013/05/19 08:47:41 ryoon Exp $
|
|--- xpcom/string/public/nsAlgorithm.h.orig	2013-05-11 19:19:56.000000000 +0000
|+++ xpcom/string/public/nsAlgorithm.h
--------------------------
Patching file xpcom/string/public/nsAlgorithm.h using Plan A...
Hunk #1 succeeded at 45.
done
===> Creating toolchain wrappers for firefox-21.0
src=/usr/pkg/lib/pkgconfig/fixesproto.pc  dst=/tmp/pkgsrc/www/firefox/work/.buildlink/lib/pkgconfig/fixesext.pc;  /bin/mkdir -p /tmp/pkgsrc/www/firefox/work/.buildlink/lib/pkgconfig;  if test -f ${src}; then  /bin/ln -sf ${src} ${dst};  fi
src=/usr/pkg/lib/pkgconfig/compositeproto.pc  dst=/tmp/pkgsrc/www/firefox/work/.buildlink/lib/pkgconfig/compositeext.pc;  /bin/mkdir -p /tmp/pkgsrc/www/firefox/work/.buildlink/lib/pkgconfig;  if test -f ${src}; then  /bin/ln -sf ${src} ${dst};  fi
===> Configuring for firefox-21.0
printf '#!/bin/sh\n[ "$*" = "-f" ] && exit 0\nexec /bin/rm $@\n' >  /tmp/pkgsrc/www/firefox/work/.wrapper/bin/rm
chmod +x /tmp/pkgsrc/www/firefox/work/.wrapper/bin/rm
=> Fixing absolute paths.
INFO: [subst.mk:fix-paths] Nothing changed in ./xpcom/build/nsXPCOMPrivate.h.
=> Fixing path to python.
cd /tmp/pkgsrc/www/firefox/work/mozilla-release && autoconf
cd /tmp/pkgsrc/www/firefox/work/mozilla-release/js/src && autoconf
mkdir /tmp/pkgsrc/www/firefox/work/mozilla-release/js/src/.deps
=> Modifying GNU configure scripts to avoid --recheck
=> Replacing config-guess with pkgsrc versions
=> Replacing config-sub with pkgsrc versions
=> Replacing install-sh with pkgsrc version
=> Checking for portability problems in extracted files
creating cache ./config.cache
checking host system type... x86_64-unknown-linux-gnu
checking target system type... x86_64-unknown-linux-gnu
checking build system type... x86_64-unknown-linux-gnu
checking for mawk... /usr/bin/awk
Using Python from environment variable $PYTHON
Creating Python environment
New python executable in /tmp/pkgsrc/www/firefox/work/mozilla-release/_virtualenv/bin/python2.7
Also creating executable in /tmp/pkgsrc/www/firefox/work/mozilla-release/_virtualenv/bin/python
Installing setuptools............done.
Installing pip...............done.
running build_ext
building '_psutil_linux' extension
creating build/temp.linux-x86_64-2.7
creating build/temp.linux-x86_64-2.7/psutil
gcc -pthread -fno-strict-aliasing -O3 -pipe -fstack-protector -Wno-error -DHAVE_DB_185_H -I/usr/include -I/usr/pkg/include/db4 -I/usr/pkg/include -I/usr/pkg/include/ncurses -DNDEBUG -O3 -pipe -fstack-protector -Wno-error -DHAVE_DB_185_H -I/usr/include -I/usr/pkg/include/db4 -I/usr/pkg/include -I/usr/pkg/include/ncurses -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -fPIC -I/usr/pkg/include/python2.7 -c psutil/_psutil_linux.c -o build/temp.linux-x86_64-2.7/psutil/_psutil_linux.o
creating build/lib.linux-x86_64-2.7
gcc -pthread -shared -L/tmp/pkgsrc/lang/python27/work/Python-2.7.4 -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 build/temp.linux-x86_64-2.7/psutil/_psutil_linux.o -L/usr/pkg/lib -lpython2.7 -o build/lib.linux-x86_64-2.7/_psutil_linux.so
building '_psutil_posix' extension
gcc -pthread -fno-strict-aliasing -O3 -pipe -fstack-protector -Wno-error -DHAVE_DB_185_H -I/usr/include -I/usr/pkg/include/db4 -I/usr/pkg/include -I/usr/pkg/include/ncurses -DNDEBUG -O3 -pipe -fstack-protector -Wno-error -DHAVE_DB_185_H -I/usr/include -I/usr/pkg/include/db4 -I/usr/pkg/include -I/usr/pkg/include/ncurses -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -fPIC -I/usr/pkg/include/python2.7 -c psutil/_psutil_posix.c -o build/temp.linux-x86_64-2.7/psutil/_psutil_posix.o
gcc -pthread -shared -L/tmp/pkgsrc/lang/python27/work/Python-2.7.4 -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 build/temp.linux-x86_64-2.7/psutil/_psutil_posix.o -L/usr/pkg/lib -lpython2.7 -o build/lib.linux-x86_64-2.7/_psutil_posix.so
copying build/lib.linux-x86_64-2.7/_psutil_linux.so -> 
copying build/lib.linux-x86_64-2.7/_psutil_posix.so -> 

checking Python environment is Mozilla virtualenv... yes
checking for /usr/pkg/bin/perl... /usr/pkg/bin/perl
checking for objcopy... /usr/bin/objcopy
checking for gcc... gcc
checking whether the C compiler (gcc -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/firefox -Wl,-R/usr/pkg/lib -lnspr4 -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) works... yes
checking whether the C compiler (gcc -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/firefox -Wl,-R/usr/pkg/lib -lnspr4 -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) is a cross-compiler... no
checking whether we are using GNU C... yes
checking whether gcc accepts -g... yes
checking for c++... g++
checking whether the C++ compiler (g++ -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/firefox -Wl,-R/usr/pkg/lib -lnspr4 -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) works... yes
checking whether the C++ compiler (g++ -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/firefox -Wl,-R/usr/pkg/lib -lnspr4 -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) is a cross-compiler... no
checking whether we are using GNU C++... yes
checking whether g++ accepts -g... yes
checking for ranlib... ranlib
checking for as... /tmp/pkgsrc/www/firefox/work/.wrapper/bin/as
checking for ar... ar
checking for ld... ld
checking for strip... strip
checking for windres... no
checking how to run the C preprocessor... gcc -E
checking how to run the C++ preprocessor... g++ -E
checking for a BSD compatible install... /usr/bin/install -c -o pbulk -g pbulk
checking whether ln -s works... yes
checking for minimum required perl version >= 5.006... 5.016003
checking for full perl installation... yes
checking for doxygen... :
checking for autoconf... /tmp/pkgsrc/www/firefox/work/.tools/bin/autoconf
checking for unzip... /tmp/pkgsrc/www/firefox/work/.tools/bin/unzip
checking for zip... /tmp/pkgsrc/www/firefox/work/.tools/bin/zip
checking for xargs... /tmp/pkgsrc/www/firefox/work/.tools/bin/xargs
checking for rpmbuild... :
checking compiler version... gcc (GCC) 4.5.2
Copyright (C) 2010 Free Software Foundation, Inc.
This is free software; see the source for copying conditions.  There is NO
warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
checking for make... /tmp/pkgsrc/www/firefox/work/.tools/bin/make
checking for X... libraries , headers 
checking for dnet_ntoa in -ldnet... no
checking for dnet_ntoa in -ldnet_stub... no
checking for gethostbyname... yes
checking for connect... yes
checking for remove... yes
checking for shmat... yes
checking for IceConnectionNumber in -lICE... yes
checking that static assertion macros used in autoconf tests work... yes
checking for --noexecstack option to as... yes
checking for -z noexecstack option to ld... yes
checking for --build-id option to ld... yes
checking if toolchain supports -mssse3 option... yes
checking if toolchain supports -msse4.1 option... yes
checking whether the C compiler supports -Werror=return-type... yes
checking whether the C compiler supports -Wtype-limits... yes
checking whether the C compiler supports -Wempty-body... yes
checking whether the C++ compiler supports -Werror=return-type... yes
checking whether the C++ compiler supports -Wtype-limits... yes
checking whether the C++ compiler supports -Wempty-body... yes
checking whether the C++ compiler supports -Wno-invalid-offsetof... yes
checking whether ld has archive extraction flags... yes
checking for 64-bit OS... yes
checking for custom <stdint.h> implementation... none specified
defined(@array) is deprecated at ./config/milestone.pl line 58.
	(Maybe you should just omit the defined()?)
defined(@array) is deprecated at ./config/milestone.pl line 58.
	(Maybe you should just omit the defined()?)
checking whether the linker supports Identical Code Folding... no
checking whether removing dead symbols breaks debugging... no
checking for ANSI C header files... yes
checking for working const... yes
checking for mode_t... yes
checking for off_t... yes
checking for pid_t... yes
checking for size_t... yes
checking for __stdcall... no
checking for ssize_t... yes
checking for st_blksize in struct stat... yes
checking for siginfo_t... yes
checking for int64... no
checking for uint... yes
checking for uint_t... no
checking for uname.domainname... yes
checking for uname.__domainname... no
checking for gcc c++0x headers bug without rtti... no
checking for usable char16_t (2 bytes, unsigned)... yes
checking for usable wchar_t (2 bytes, unsigned)... no
checking for visibility(hidden) attribute... yes
checking for visibility(default) attribute... yes
checking for visibility pragma support... yes
checking For gcc visibility bug with class-level attributes (GCC bug 26905)... no
checking For x86_64 gcc visibility bug with builtins (GCC bug 20297)... no
checking for gcc PR49911... no
checking for gcc pr39608... no
checking for llvm pr8927... no
checking for __force_align_arg_pointer__ attribute... no
checking for dirent.h that defines DIR... yes
checking for opendir in -ldir... no
checking for sys/byteorder.h... no
checking for compat.h... no
checking for getopt.h... yes
checking for sys/bitypes.h... yes
checking for memory.h... yes
checking for unistd.h... yes
checking for gnu/libc-version.h... yes
checking for nl_types.h... yes
checking for malloc.h... yes
checking for X11/XKBlib.h... yes
checking for io.h... no
checking for cpuid.h... yes
checking for sys/statvfs.h... yes
checking for sys/statfs.h... yes
checking for sys/vfs.h... yes
checking for sys/mount.h... yes
checking for sys/quota.h... yes
checking for sys/sysmacros.h... yes
checking for linux/quota.h... yes
checking for linux/if_addr.h... yes
checking for linux/rtnetlink.h... yes
checking for sys/types.h... yes
checking for netinet/in.h... yes
checking for byteswap.h... yes
checking for sockaddr_in.sin_len... false
checking for sockaddr_in6.sin6_len... false
checking for sockaddr.sa_len... false
checking for new... yes
checking for sys/cdefs.h... yes
checking for linux/perf_event.h... yes
checking for perf_event_open system call... yes
checking for gethostbyname_r in -lc_r... no
checking for library containing dlopen... none required
checking for dlfcn.h... yes
checking for dladdr... yes
checking for memmem... yes
checking for socket in -lsocket... no
checking for XDrawLines in -lX11... yes
checking for XextAddDisplay in -lXext... yes
checking for XtFree in -lXt... yes
checking for XShmCreateImage in -lXext... yes
checking for X11/extensions/scrnsaver.h... no
checking for pthread_create in -lpthreads... no
checking for pthread_create in -lpthread... yes
checking whether gcc accepts -pthread... yes
checking whether gcc needs -traditional... no
checking for 8-bit clean memcmp... yes
checking for random... yes
checking for strerror... yes
checking for lchown... yes
checking for fchmod... yes
checking for snprintf... yes
checking for memmove... yes
checking for rint... no
checking for stat64... yes
checking for lstat64... yes
checking for truncate64... yes
checking for setbuf... yes
checking for isatty... yes
checking for statvfs64... yes
checking for statvfs... yes
checking for statfs64... yes
checking for statfs... yes
checking for flockfile... yes
checking for getpagesize... yes
checking for localtime_r... yes
checking for strtok_r... yes
checking for clock_gettime(CLOCK_MONOTONIC)... 
checking for wcrtomb... yes
checking for mbrtowc... yes
checking for res_ninit()... yes
checking for gnu_get_libc_version()... yes
checking for iconv in -lc... yes
checking for iconv()... yes
checking for iconv() with const input... no
checking for nl_langinfo and CODESET... yes
checking for an implementation of va_copy()... yes
checking for an implementation of __va_copy()... yes
checking whether va_lists can be copied by value... no
checking for modern C++ template specialization syntax support... yes
checking whether partial template specialization works... yes
checking whether the C++ "using" keyword resolves ambiguity... yes
checking for C++ dynamic_cast to void*... yes
checking whether C++ requires implementation of unused virtual methods... no
checking for trouble comparing to zero near std::operator!=()... no
checking for __thread keyword for TLS variables... yes
checking for malloc.h... (cached) yes
checking for strndup... yes
checking for posix_memalign... yes
checking for memalign... yes
checking for valloc... yes
checking for malloc_usable_size... yes
checking for __attribute__((always_inline))... yes
checking for __attribute__((malloc))... yes
checking for __attribute__((warn_unused_result))... yes
checking for LC_MESSAGES... yes
checking for localeconv... yes
checking for nspr-config... /usr/pkg/bin/nspr-config
checking for NSPR - version >= 4.9.6... yes
checking for event.h... yes
checking for event_init in -levent... yes
checking for pkg-config... /tmp/pkgsrc/www/firefox/work/.tools/bin/pkg-config
checking for NSS - version >= 3.14.3... yes
checking for YASM assembler... checking for yasm... yasm
checking for gzread in -lz... yes
checking for BZ2_bzread in -lbz2... yes
checking for hunspell... yes
checking MOZ_HUNSPELL_CFLAGS... -I/usr/pkg/include/hunspell 
checking MOZ_HUNSPELL_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lhunspell-1.3 
checking for libffi >= 3.0.9... yes
checking MOZ_FFI_CFLAGS... -I/usr/pkg/include 
checking MOZ_FFI_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lffi 
checking for application to build... browser
checking if app-specific confvars.sh exists... ./browser/confvars.sh
checking for gtk+-2.0 >= 2.10.0 gtk+-unix-print-2.0 glib-2.0 gobject-2.0 gdk-x11-2.0... yes
checking MOZ_GTK2_CFLAGS... -D_REENTRANT -pthread -I/usr/pkg/include/gtk-2.0 -I/usr/pkg/include/gtk-unix-print-2.0 -I/usr/pkg/include/gtk-2.0 -I/usr/pkg/include/atk-1.0 -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/harfbuzz -I/usr/pkg/include/gtk-2.0 -I/usr/pkg/lib/gtk-2.0/include -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/cairo -I/usr/pkg/include/pixman-1 -I/usr/pkg/include -I/usr/pkg/include/freetype2 -I/usr/pkg/include -I/usr/pkg/include/libpng16 -I/usr/pkg/include -I/usr/pkg/include/gdk-pixbuf-2.0 -I/usr/pkg/include/libpng16 -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include 
checking MOZ_GTK2_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lgtk-x11-2.0 -Wl,-R/usr/pkg/lib -lgtk-x11-2.0 -Wl,-R/usr/pkg/lib -latk-1.0 -Wl,-R/usr/pkg/lib -lgio-2.0 -Wl,-R/usr/pkg/lib -lpangoft2-1.0 -Wl,-R/usr/pkg/lib -lfreetype -Wl,-R/usr/pkg/lib -lfontconfig -Wl,-R/usr/pkg/lib -lgdk-x11-2.0 -Wl,-R/usr/pkg/lib -lpangocairo-1.0 -Wl,-R/usr/pkg/lib -lpango-1.0 -Wl,-R/usr/pkg/lib -lcairo -Wl,-R/usr/pkg/lib -lgdk_pixbuf-2.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 
checking for pango >= 1.14.0... yes
checking _PANGOCHK_CFLAGS... -pthread -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include 
checking _PANGOCHK_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lpango-1.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 
checking for pango >= 1.14.0 pangoft2 >= 1.14.0 pangocairo >= 1.14.0... yes
checking MOZ_PANGO_CFLAGS... -pthread -D_REENTRANT -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/harfbuzz -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include -I/usr/pkg/include/cairo -I/usr/pkg/include/pixman-1 -I/usr/pkg/include -I/usr/pkg/include/freetype2 -I/usr/pkg/include -I/usr/pkg/include/libpng16 -I/usr/pkg/include 
checking MOZ_PANGO_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lpangoft2-1.0 -Wl,-R/usr/pkg/lib -lfreetype -Wl,-R/usr/pkg/lib -lfontconfig -Wl,-R/usr/pkg/lib -lpangocairo-1.0 -Wl,-R/usr/pkg/lib -lpango-1.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 -Wl,-R/usr/pkg/lib -lcairo 
checking for gtk+-2.0 >= 2.14... yes
checking _GTKCHECK_CFLAGS... -D_REENTRANT -pthread -I/usr/pkg/include/gtk-2.0 -I/usr/pkg/lib/gtk-2.0/include -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/atk-1.0 -I/usr/pkg/include/cairo -I/usr/pkg/include/pixman-1 -I/usr/pkg/include/libpng16 -I/usr/pkg/include -I/usr/pkg/include/gdk-pixbuf-2.0 -I/usr/pkg/include/libpng16 -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/harfbuzz -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include -I/usr/pkg/include/freetype2 -I/usr/pkg/include 
checking _GTKCHECK_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lgtk-x11-2.0 -Wl,-R/usr/pkg/lib -lgdk-x11-2.0 -Wl,-R/usr/pkg/lib -lpangocairo-1.0 -Wl,-R/usr/pkg/lib -latk-1.0 -Wl,-R/usr/pkg/lib -lcairo -Wl,-R/usr/pkg/lib -lgdk_pixbuf-2.0 -Wl,-R/usr/pkg/lib -lgio-2.0 -Wl,-R/usr/pkg/lib -lpangoft2-1.0 -Wl,-R/usr/pkg/lib -lpango-1.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 -Wl,-R/usr/pkg/lib -lfreetype -Wl,-R/usr/pkg/lib -lfontconfig 
checking for gio-2.0 >= 2.20... yes
checking MOZ_GIO_CFLAGS... -pthread -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include 
checking MOZ_GIO_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lgio-2.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 
checking for gconf-2.0 >= 1.2.1 gobject-2.0 ... checking for libv4l2... Package libv4l2 was not found in the pkg-config search path. Perhaps you should add the directory containing `libv4l2.pc' to the PKG_CONFIG_PATH environment variable No package 'libv4l2' found
configure: error: Library requirements (libv4l2) not met; consider adjusting the PKG_CONFIG_PATH environment variable if your libraries are in a nonstandard prefix so pkg-config can find them.
*** Error code 1

Stop.
bmake: stopped in /usr/pkgsrc/www/firefox
*** Error code 1

Stop.
bmake: stopped in /usr/pkgsrc/www/firefox
